'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var getInitialState = function getInitialState(_ref) {
  var valid = _ref.valid,
      value = _ref.value,
      validate = _ref.validate,
      _ref$disabled = _ref.disabled,
      disabled = _ref$disabled === undefined ? false : _ref$disabled;

  // default values
  var defaults = {
    valid: !validate,
    value: '',
    dirty: false,
    errorMessage: ''
  };
  if (value) {
    if (validate) {
      // default values when the input has a value and a validate prop
      var validateObj = validate(value);
      defaults = {
        value: value,
        valid: validateObj.valid,
        errorMessage: validateObj.errorMessage,
        dirty: true
      };
    } else {
      // default values when the input has a value but has not a validate prop
      defaults = {
        valid: true,
        value: value,
        dirty: true,
        errorMessage: ''
      };
    }
  }

  return _extends({}, defaults, { defaults: defaults, resetValue: false, disabled: disabled, needToValidate: validate });
};

var getStateOnBackendErrors = function getStateOnBackendErrors() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var errors = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var inputs = state.inputs;

  for (var input in errors) {
    inputs[input] = _extends({}, inputs[input], {
      valid: false,
      errorMessage: errors[input]
    });
  }
  return _extends({}, state);
};

var getStateOnResetForm = function getStateOnResetForm() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var clearValues = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
  var inputs = state.inputs;

  for (var input in inputs) {
    var _inputs$input$default = inputs[input].defaults,
        valid = _inputs$input$default.valid,
        value = _inputs$input$default.value,
        dirty = _inputs$input$default.dirty;

    inputs[input] = _extends({}, inputs[input], {
      resetValue: true,
      valid: clearValues ? !inputs[input].needToValidate : valid,
      dirty: clearValues ? false : dirty,
      value: clearValues ? '' : value
    });
  }
  return _extends({}, state, {
    forceDirty: false
  });
};

var getStateWithNewInputValues = function getStateWithNewInputValues() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var newValues = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var input = arguments[2];
  var inputs = state.inputs;

  if (input) {
    inputs[input] = _extends({}, inputs[input], newValues);
  } else {
    for (var _input in inputs) {
      inputs[_input] = _extends({}, inputs[_input], newValues);
    }
  }

  return _extends({}, state);
};

var getInputsValues = function getInputsValues() {
  var inputs = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

  for (var input in inputs) {
    inputs[input] = inputs[input].value;
  }
  return inputs;
};

exports.getInitialState = getInitialState;
exports.getStateOnBackendErrors = getStateOnBackendErrors;
exports.getStateOnResetForm = getStateOnResetForm;
exports.getStateWithNewInputValues = getStateWithNewInputValues;
exports.getInputsValues = getInputsValues;
;

var _temp = function () {
  if (typeof __REACT_HOT_LOADER__ === 'undefined') {
    return;
  }

  __REACT_HOT_LOADER__.register(getInitialState, 'getInitialState', 'src/form/form.js');

  __REACT_HOT_LOADER__.register(getStateOnBackendErrors, 'getStateOnBackendErrors', 'src/form/form.js');

  __REACT_HOT_LOADER__.register(getStateOnResetForm, 'getStateOnResetForm', 'src/form/form.js');

  __REACT_HOT_LOADER__.register(getStateWithNewInputValues, 'getStateWithNewInputValues', 'src/form/form.js');

  __REACT_HOT_LOADER__.register(getInputsValues, 'getInputsValues', 'src/form/form.js');
}();

;
//# sourceMappingURL=form.js.map